@@ -15,7 +15,7 @@
  * paragraphs for information about pppstatus and the license.
  *
  *****************************************************************************
- * $Id: slurm.c,v 1.84 2004/02/13 05:41:30 hscholz Exp $
+ * $Id: slurm.c,v 1.86 2004/10/12 19:44:36 hscholz Exp $
  *****************************************************************************
  *
  * This program is free software; you can redistribute it and/or modify
@@ -68,6 +68,9 @@
 #elif __APPLE__
 #include "src/macos.h"
 #include "src/macos.c"
+#elif __DragonFly__
+#include "src/freebsd.h"
+#include "src/freebsd.c"
 #else
 #warning "Your OS is not supported. Including dummy code!"
 #include "src/unsupported.h"
@@ -1371,7 +1374,7 @@ int main(int argc, char *argv[])
    return 0;
 #endif
 
-#ifndef __HPUX__
+#ifndef NO_CURSES_E
     printf("\e(U"); 
 #endif
 
@@ -1480,7 +1483,7 @@ int main(int argc, char *argv[])
 		tmpdelay = refreshdelay * 10;
 		do
 		{
-			usleep(100*1000); // 10th of a second
+			usleep(100*1000); /* 10th of a second */
 			tmpdelay--;
 			key_pressed = getch();
 			if (key_pressed != ERR)
